import { pgTable, uuid, varchar, text, timestamp, jsonb, index } from 'drizzle-orm/pg-core';
import { users } from './users';

/**
 * Projects table schema
 */
export const projects = pgTable('projects', {
  id: uuid('id').primaryKey().defaultRandom(),
  name: varchar('name', { length: 100 }).notNull(),
  description: text('description'),
  ownerId: uuid('ownerId').notNull().references(() => users.id, { onDelete: 'cascade' }),
  settings: jsonb('settings').default({}),
  createdAt: timestamp('createdAt', { withTimezone: true }).defaultNow().notNull(),
  updatedAt: timestamp('updatedAt', { withTimezone: true }).defaultNow().notNull()
}, (table) => {
  return {
    nameIdx: index('project_name_idx').on(table.name),
    ownerIdIdx: index('project_ownerId_idx').on(table.ownerId),
    createdAtIdx: index('project_createdAt_idx').on(table.createdAt)
  };
});

/**
 * Project type definitions
 */
export type Project = typeof projects.$inferSelect;
export type NewProject = typeof projects.$inferInsert;
