import { IsString, IsNotEmpty, IsOptional, IsObject } from 'class-validator';
import { ApiProperty } from '@nestjs/swagger';

/**
 * DTO for creating a new user
 */
export class CreateUserDto {
  @ApiProperty({
    description: 'The name of the user',
    example: 'John Doe'
  })
  @IsString()
  @IsNotEmpty()
  name: string;

  @ApiProperty({
    description: 'The avatar URL of the user',
    example: 'https://example.com/avatar.png',
    required: false
  })
  @IsString()
  @IsOptional()
  avatar?: string;

  @ApiProperty({
    description: 'The GitHub ID of the user',
    example: 'github123456'
  })
  @IsString()
  @IsNotEmpty()
  githubId: string;

  @ApiProperty({
    description: 'Additional metadata for the user',
    example: { email: 'john.doe@example.com' },
    required: false
  })
  @IsObject()
  @IsOptional()
  metadata?: Record<string, any>;
}
